@@ -25,7 +25,7 @@ manyglm <- function (formula,
 
 
 # start by converting any family objects that can be handled over to character strings
-if(class(family)=="family"){
+if(inherits(family,"family")){
   fam = family
   if(fam$family=="binomial" & fam$link=="cloglog")
     family="cloglog"
@@ -127,8 +127,8 @@ if(composition==TRUE)
     #DW edits, 1/2/22, so works when data is a list (like Code Box 14.6 of Eco-Stats text)
     whichResponse=which(names(data)==names(mf[1]))
     if(inherits(data,"data.frame")==FALSE)
-      data2 = as.data.frame(data[-whichResponse])
-    dat = data.frame(c(Y), data2[rep(1:N,p),])
+      data = as.data.frame(data[-whichResponse])
+    dat = data.frame(c(Y), data[rep(1:N,p),])
     names(dat)[1] = names(mf)[1]  #match name to original object
     whichResponse=1
     # end DW edits
